==> apache-brooklyn-0.9.0-rc2-src.zip: apache-brooklyn-0.9.0-src/brooklyn-server/launcher/src/test/java/org/apache/brooklyn/launcher/blueprints/MongoDbBlueprintTest.java <==
/*
 * Licensed to the Apache Software Foundation (ASF) under one
 * or more contributor license agreements.  See the NOTICE file
 * distributed with this work for additional information
 * regarding copyright ownership.  The ASF licenses this file
 * to you under the Apache License, Version 2.0 (the
 * "License"); you may not use this file except in compliance
 * with the License.  You may obtain a copy of the License at
 *
 *     http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing,
 * software distributed under the License is distributed on an
 * "AS IS" BASIS, WITHOUT WARRANTIES OR CONDITIONS OF ANY
 * KIND, either express or implied.  See the License for the
 * specific language governing permissions and limitations
 * under the License.
 */
package org.apache.brooklyn.launcher.blueprints;

import org.testng.annotations.Test;

public class MongoDbBlueprintTest extends AbstractBlueprintTest {

    // TODO Some tests are failing! Needs investigated.

    @Test(groups={"Integration", "WIP"})
    public void testMongoSharded() throws Exception {
        runTest("mongo-sharded.yaml");
    }

    @Test(groups={"Integration"})
    public void testMongoReplicaSet() throws Exception {
        runTest("mongo-blueprint.yaml");
    }

    @Test(groups={"Integration"})
    public void testMongoClientAndSingleServer() throws Exception {
        runTest("mongo-client-single-server.yaml");
    }

    @Test(groups={"Integration", "WIP"})
    public void testMongoScripts() throws Exception {
        runTest("mongo-scripts.yaml");
    }

    @Test(groups="Integration")
    public void testMongoSingleServer() throws Exception {
        runTest("mongo-single-server-blueprint.yaml");
    }
}

==> apache-brooklyn-1.1.0-src.zip: apache-brooklyn-1.1.0-src/brooklyn-server/launcher/src/test/java/org/apache/brooklyn/launcher/blueprints/MongoDbBlueprintTest.java <==
/*
 * Licensed to the Apache Software Foundation (ASF) under one
 * or more contributor license agreements.  See the NOTICE file
 * distributed with this work for additional information
 * regarding copyright ownership.  The ASF licenses this file
 * to you under the Apache License, Version 2.0 (the
 * "License"); you may not use this file except in compliance
 * with the License.  You may obtain a copy of the License at
 *
 *     http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing,
 * software distributed under the License is distributed on an
 * "AS IS" BASIS, WITHOUT WARRANTIES OR CONDITIONS OF ANY
 * KIND, either express or implied.  See the License for the
 * specific language governing permissions and limitations
 * under the License.
 */
package org.apache.brooklyn.launcher.blueprints;

import org.testng.annotations.Test;

public class MongoDbBlueprintTest extends AbstractBlueprintTest {

    // TODO Some tests are failing! Needs investigated.

    @Test(groups={"Integration", "WIP", "Broken"})
    public void testMongoSharded() throws Exception {
        runTest("mongo-sharded.yaml");
    }

    @Test(groups={"Integration", "Broken"})
    public void testMongoReplicaSet() throws Exception {
        runTest("mongo-blueprint.yaml");
    }

    @Test(groups={"Integration", "Broken"})
    public void testMongoClientAndSingleServer() throws Exception {
        runTest("mongo-client-single-server.yaml");
    }

    @Test(groups={"Integration", "WIP", "Broken"})
    public void testMongoScripts() throws Exception {
        runTest("mongo-scripts.yaml");
    }

    @Test(groups={"Integration", "Broken"})
    public void testMongoSingleServer() throws Exception {
        runTest("mongo-single-server-blueprint.yaml");
    }
}
